==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/cfg/kotlin/inputs/RecorderRecordingGroupRecordingStrategyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.cfg.kotlin.inputs

import com.pulumi.aws.cfg.inputs.RecorderRecordingGroupRecordingStrategyArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property useOnly
 */
public data class RecorderRecordingGroupRecordingStrategyArgs(
    public val useOnly: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.cfg.inputs.RecorderRecordingGroupRecordingStrategyArgs> {
    override fun toJava(): com.pulumi.aws.cfg.inputs.RecorderRecordingGroupRecordingStrategyArgs =
        com.pulumi.aws.cfg.inputs.RecorderRecordingGroupRecordingStrategyArgs.builder()
            .useOnly(useOnly?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [RecorderRecordingGroupRecordingStrategyArgs].
 */
@PulumiTagMarker
public class RecorderRecordingGroupRecordingStrategyArgsBuilder internal constructor() {
    private var useOnly: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("gfjvqetxalppqvyv")
    public suspend fun useOnly(`value`: Output<String>) {
        this.useOnly = value
    }

    /**
     * @param value
     */
    @JvmName("jghvwylibkmeidve")
    public suspend fun useOnly(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.useOnly = mapped
    }

    internal fun build(): RecorderRecordingGroupRecordingStrategyArgs =
        RecorderRecordingGroupRecordingStrategyArgs(
            useOnly = useOnly,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/cfg/kotlin/inputs/RecorderRecordingGroupRecordingStrategyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.cfg.kotlin.inputs

import com.pulumi.aws.cfg.inputs.RecorderRecordingGroupRecordingStrategyArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property useOnly
 */
public data class RecorderRecordingGroupRecordingStrategyArgs(
    public val useOnly: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.cfg.inputs.RecorderRecordingGroupRecordingStrategyArgs> {
    override fun toJava(): com.pulumi.aws.cfg.inputs.RecorderRecordingGroupRecordingStrategyArgs =
        com.pulumi.aws.cfg.inputs.RecorderRecordingGroupRecordingStrategyArgs.builder()
            .useOnly(useOnly?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [RecorderRecordingGroupRecordingStrategyArgs].
 */
@PulumiTagMarker
public class RecorderRecordingGroupRecordingStrategyArgsBuilder internal constructor() {
    private var useOnly: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("vocrvcrscyrmyxmh")
    public suspend fun useOnly(`value`: Output<String>) {
        this.useOnly = value
    }

    /**
     * @param value
     */
    @JvmName("eliupwhhpkxohidw")
    public suspend fun useOnly(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.useOnly = mapped
    }

    internal fun build(): RecorderRecordingGroupRecordingStrategyArgs =
        RecorderRecordingGroupRecordingStrategyArgs(
            useOnly = useOnly,
        )
}
